@@ -3,6 +3,16 @@ from pkg_resources import resource_filename
 
 
 def get_data(folder: str, filename: str) -> list[str]:
+    '''
+    Returns list of strings gathered from a certain datafile in a certain folder
+
+    Args:
+        folder (str): The name of a folder
+        filename (str): The name of a datafile
+
+    Returns:
+        list[str]: The gathered list of strings
+    '''
     words = []
     data_path = Path(resource_filename('randword', 'data'))
     filepath = data_path / folder / f'{filename}.txt'
